==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/opensearch/kotlin/inputs/DomainClusterConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.opensearch.kotlin.inputs

import com.pulumi.aws.opensearch.inputs.DomainClusterConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property coldStorageOptions Configuration block containing cold storage configuration. Detailed below.
 * @property dedicatedMasterCount Number of dedicated main nodes in the cluster.
 * @property dedicatedMasterEnabled Whether dedicated main nodes are enabled for the cluster.
 * @property dedicatedMasterType Instance type of the dedicated main nodes in the cluster.
 * @property instanceCount Number of instances in the cluster.
 * @property instanceType Instance type of data nodes in the cluster.
 * @property multiAzWithStandbyEnabled
 * @property warmCount Number of warm nodes in the cluster. Valid values are between `2` and `150`. `warm_count` can be only and must be set when `warm_enabled` is set to `true`.
 * @property warmEnabled Whether to enable warm storage.
 * @property warmType Instance type for the OpenSearch cluster's warm nodes. Valid values are `ultrawarm1.medium.search`, `ultrawarm1.large.search` and `ultrawarm1.xlarge.search`. `warm_type` can be only and must be set when `warm_enabled` is set to `true`.
 * @property zoneAwarenessConfig Configuration block containing zone awareness settings. Detailed below.
 * @property zoneAwarenessEnabled Whether zone awareness is enabled, set to `true` for multi-az deployment. To enable awareness with three Availability Zones, the `availability_zone_count` within the `zone_awareness_config` must be set to `3`.
 */
public data class DomainClusterConfigArgs(
    public val coldStorageOptions: Output<DomainClusterConfigColdStorageOptionsArgs>? = null,
    public val dedicatedMasterCount: Output<Int>? = null,
    public val dedicatedMasterEnabled: Output<Boolean>? = null,
    public val dedicatedMasterType: Output<String>? = null,
    public val instanceCount: Output<Int>? = null,
    public val instanceType: Output<String>? = null,
    public val multiAzWithStandbyEnabled: Output<Boolean>? = null,
    public val warmCount: Output<Int>? = null,
    public val warmEnabled: Output<Boolean>? = null,
    public val warmType: Output<String>? = null,
    public val zoneAwarenessConfig: Output<DomainClusterConfigZoneAwarenessConfigArgs>? = null,
    public val zoneAwarenessEnabled: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.aws.opensearch.inputs.DomainClusterConfigArgs> {
    override fun toJava(): com.pulumi.aws.opensearch.inputs.DomainClusterConfigArgs =
        com.pulumi.aws.opensearch.inputs.DomainClusterConfigArgs.builder()
            .coldStorageOptions(
                coldStorageOptions?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .dedicatedMasterCount(dedicatedMasterCount?.applyValue({ args0 -> args0 }))
            .dedicatedMasterEnabled(dedicatedMasterEnabled?.applyValue({ args0 -> args0 }))
            .dedicatedMasterType(dedicatedMasterType?.applyValue({ args0 -> args0 }))
            .instanceCount(instanceCount?.applyValue({ args0 -> args0 }))
            .instanceType(instanceType?.applyValue({ args0 -> args0 }))
            .multiAzWithStandbyEnabled(multiAzWithStandbyEnabled?.applyValue({ args0 -> args0 }))
            .warmCount(warmCount?.applyValue({ args0 -> args0 }))
            .warmEnabled(warmEnabled?.applyValue({ args0 -> args0 }))
            .warmType(warmType?.applyValue({ args0 -> args0 }))
            .zoneAwarenessConfig(
                zoneAwarenessConfig?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .zoneAwarenessEnabled(zoneAwarenessEnabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DomainClusterConfigArgs].
 */
@PulumiTagMarker
public class DomainClusterConfigArgsBuilder internal constructor() {
    private var coldStorageOptions: Output<DomainClusterConfigColdStorageOptionsArgs>? = null

    private var dedicatedMasterCount: Output<Int>? = null

    private var dedicatedMasterEnabled: Output<Boolean>? = null

    private var dedicatedMasterType: Output<String>? = null

    private var instanceCount: Output<Int>? = null

    private var instanceType: Output<String>? = null

    private var multiAzWithStandbyEnabled: Output<Boolean>? = null

    private var warmCount: Output<Int>? = null

    private var warmEnabled: Output<Boolean>? = null

    private var warmType: Output<String>? = null

    private var zoneAwarenessConfig: Output<DomainClusterConfigZoneAwarenessConfigArgs>? = null

    private var zoneAwarenessEnabled: Output<Boolean>? = null

    /**
     * @param value Configuration block containing cold storage configuration. Detailed below.
     */
    @JvmName("pcpxhpistkuatdtk")
    public suspend
    fun coldStorageOptions(`value`: Output<DomainClusterConfigColdStorageOptionsArgs>) {
        this.coldStorageOptions = value
    }

    /**
     * @param value Number of dedicated main nodes in the cluster.
     */
    @JvmName("paxeefepxqfrqmdv")
    public suspend fun dedicatedMasterCount(`value`: Output<Int>) {
        this.dedicatedMasterCount = value
    }

    /**
     * @param value Whether dedicated main nodes are enabled for the cluster.
     */
    @JvmName("uevvcbxosdueosrm")
    public suspend fun dedicatedMasterEnabled(`value`: Output<Boolean>) {
        this.dedicatedMasterEnabled = value
    }

    /**
     * @param value Instance type of the dedicated main nodes in the cluster.
     */
    @JvmName("nqnmxsnbpidjxjwg")
    public suspend fun dedicatedMasterType(`value`: Output<String>) {
        this.dedicatedMasterType = value
    }

    /**
     * @param value Number of instances in the cluster.
     */
    @JvmName("huhekqlavtfdbhmy")
    public suspend fun instanceCount(`value`: Output<Int>) {
        this.instanceCount = value
    }

    /**
     * @param value Instance type of data nodes in the cluster.
     */
    @JvmName("wmivceblnkwcvlli")
    public suspend fun instanceType(`value`: Output<String>) {
        this.instanceType = value
    }

    /**
     * @param value
     */
    @JvmName("qlpkvxmrnaalcjno")
    public suspend fun multiAzWithStandbyEnabled(`value`: Output<Boolean>) {
        this.multiAzWithStandbyEnabled = value
    }

    /**
     * @param value Number of warm nodes in the cluster. Valid values are between `2` and `150`. `warm_count` can be only and must be set when `warm_enabled` is set to `true`.
     */
    @JvmName("cgjxdiwuelnkheoh")
    public suspend fun warmCount(`value`: Output<Int>) {
        this.warmCount = value
    }

    /**
     * @param value Whether to enable warm storage.
     */
    @JvmName("kwbauynyxuydjfsw")
    public suspend fun warmEnabled(`value`: Output<Boolean>) {
        this.warmEnabled = value
    }

    /**
     * @param value Instance type for the OpenSearch cluster's warm nodes. Valid values are `ultrawarm1.medium.search`, `ultrawarm1.large.search` and `ultrawarm1.xlarge.search`. `warm_type` can be only and must be set when `warm_enabled` is set to `true`.
     */
    @JvmName("aubiysakvdclmkoy")
    public suspend fun warmType(`value`: Output<String>) {
        this.warmType = value
    }

    /**
     * @param value Configuration block containing zone awareness settings. Detailed below.
     */
    @JvmName("ewpdvaachcuqqeku")
    public suspend
    fun zoneAwarenessConfig(`value`: Output<DomainClusterConfigZoneAwarenessConfigArgs>) {
        this.zoneAwarenessConfig = value
    }

    /**
     * @param value Whether zone awareness is enabled, set to `true` for multi-az deployment. To enable awareness with three Availability Zones, the `availability_zone_count` within the `zone_awareness_config` must be set to `3`.
     */
    @JvmName("exshdyuunssuxheq")
    public suspend fun zoneAwarenessEnabled(`value`: Output<Boolean>) {
        this.zoneAwarenessEnabled = value
    }

    /**
     * @param value Configuration block containing cold storage configuration. Detailed below.
     */
    @JvmName("wlixsjpunngwnacn")
    public suspend fun coldStorageOptions(`value`: DomainClusterConfigColdStorageOptionsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.coldStorageOptions = mapped
    }

    /**
     * @param argument Configuration block containing cold storage configuration. Detailed below.
     */
    @JvmName("cnffnahbwqylumeu")
    public suspend
    fun coldStorageOptions(argument: suspend DomainClusterConfigColdStorageOptionsArgsBuilder.() -> Unit) {
        val toBeMapped = DomainClusterConfigColdStorageOptionsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.coldStorageOptions = mapped
    }

    /**
     * @param value Number of dedicated main nodes in the cluster.
     */
    @JvmName("ecjapuwaqmtajpvk")
    public suspend fun dedicatedMasterCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dedicatedMasterCount = mapped
    }

    /**
     * @param value Whether dedicated main nodes are enabled for the cluster.
     */
    @JvmName("tyukjkqinjhecrsq")
    public suspend fun dedicatedMasterEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dedicatedMasterEnabled = mapped
    }

    /**
     * @param value Instance type of the dedicated main nodes in the cluster.
     */
    @JvmName("slskwxilgekvcpnw")
    public suspend fun dedicatedMasterType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dedicatedMasterType = mapped
    }

    /**
     * @param value Number of instances in the cluster.
     */
    @JvmName("nbeimxwukqujsako")
    public suspend fun instanceCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.instanceCount = mapped
    }

    /**
     * @param value Instance type of data nodes in the cluster.
     */
    @JvmName("fqbstbsqxeygpqlf")
    public suspend fun instanceType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.instanceType = mapped
    }

    /**
     * @param value
     */
    @JvmName("nxechmklewareoqq")
    public suspend fun multiAzWithStandbyEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.multiAzWithStandbyEnabled = mapped
    }

    /**
     * @param value Number of warm nodes in the cluster. Valid values are between `2` and `150`. `warm_count` can be only and must be set when `warm_enabled` is set to `true`.
     */
    @JvmName("xpwmbvpjcupwmjid")
    public suspend fun warmCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.warmCount = mapped
    }

    /**
     * @param value Whether to enable warm storage.
     */
    @JvmName("sgqsopubvbcoxopm")
    public suspend fun warmEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.warmEnabled = mapped
    }

    /**
     * @param value Instance type for the OpenSearch cluster's warm nodes. Valid values are `ultrawarm1.medium.search`, `ultrawarm1.large.search` and `ultrawarm1.xlarge.search`. `warm_type` can be only and must be set when `warm_enabled` is set to `true`.
     */
    @JvmName("fmbpvdvxrqdscsgs")
    public suspend fun warmType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.warmType = mapped
    }

    /**
     * @param value Configuration block containing zone awareness settings. Detailed below.
     */
    @JvmName("ngfdrkrnratywkpq")
    public suspend fun zoneAwarenessConfig(`value`: DomainClusterConfigZoneAwarenessConfigArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.zoneAwarenessConfig = mapped
    }

    /**
     * @param argument Configuration block containing zone awareness settings. Detailed below.
     */
    @JvmName("wevjpqttekwyxnnv")
    public suspend
    fun zoneAwarenessConfig(argument: suspend DomainClusterConfigZoneAwarenessConfigArgsBuilder.() -> Unit) {
        val toBeMapped = DomainClusterConfigZoneAwarenessConfigArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.zoneAwarenessConfig = mapped
    }

    /**
     * @param value Whether zone awareness is enabled, set to `true` for multi-az deployment. To enable awareness with three Availability Zones, the `availability_zone_count` within the `zone_awareness_config` must be set to `3`.
     */
    @JvmName("kgttxwqjuywcrvcs")
    public suspend fun zoneAwarenessEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.zoneAwarenessEnabled = mapped
    }

    internal fun build(): DomainClusterConfigArgs = DomainClusterConfigArgs(
        coldStorageOptions = coldStorageOptions,
        dedicatedMasterCount = dedicatedMasterCount,
        dedicatedMasterEnabled = dedicatedMasterEnabled,
        dedicatedMasterType = dedicatedMasterType,
        instanceCount = instanceCount,
        instanceType = instanceType,
        multiAzWithStandbyEnabled = multiAzWithStandbyEnabled,
        warmCount = warmCount,
        warmEnabled = warmEnabled,
        warmType = warmType,
        zoneAwarenessConfig = zoneAwarenessConfig,
        zoneAwarenessEnabled = zoneAwarenessEnabled,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/opensearch/kotlin/inputs/DomainClusterConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.opensearch.kotlin.inputs

import com.pulumi.aws.opensearch.inputs.DomainClusterConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property coldStorageOptions Configuration block containing cold storage configuration. Detailed below.
 * @property dedicatedMasterCount Number of dedicated main nodes in the cluster.
 * @property dedicatedMasterEnabled Whether dedicated main nodes are enabled for the cluster.
 * @property dedicatedMasterType Instance type of the dedicated main nodes in the cluster.
 * @property instanceCount Number of instances in the cluster.
 * @property instanceType Instance type of data nodes in the cluster.
 * @property multiAzWithStandbyEnabled Whether a multi-AZ domain is turned on with a standby AZ. For more information, see [Configuring a multi-AZ domain in Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/managedomains-multiaz.html).
 * @property warmCount Number of warm nodes in the cluster. Valid values are between `2` and `150`. `warm_count` can be only and must be set when `warm_enabled` is set to `true`.
 * @property warmEnabled Whether to enable warm storage.
 * @property warmType Instance type for the OpenSearch cluster's warm nodes. Valid values are `ultrawarm1.medium.search`, `ultrawarm1.large.search` and `ultrawarm1.xlarge.search`. `warm_type` can be only and must be set when `warm_enabled` is set to `true`.
 * @property zoneAwarenessConfig Configuration block containing zone awareness settings. Detailed below.
 * @property zoneAwarenessEnabled Whether zone awareness is enabled, set to `true` for multi-az deployment. To enable awareness with three Availability Zones, the `availability_zone_count` within the `zone_awareness_config` must be set to `3`.
 */
public data class DomainClusterConfigArgs(
    public val coldStorageOptions: Output<DomainClusterConfigColdStorageOptionsArgs>? = null,
    public val dedicatedMasterCount: Output<Int>? = null,
    public val dedicatedMasterEnabled: Output<Boolean>? = null,
    public val dedicatedMasterType: Output<String>? = null,
    public val instanceCount: Output<Int>? = null,
    public val instanceType: Output<String>? = null,
    public val multiAzWithStandbyEnabled: Output<Boolean>? = null,
    public val warmCount: Output<Int>? = null,
    public val warmEnabled: Output<Boolean>? = null,
    public val warmType: Output<String>? = null,
    public val zoneAwarenessConfig: Output<DomainClusterConfigZoneAwarenessConfigArgs>? = null,
    public val zoneAwarenessEnabled: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.aws.opensearch.inputs.DomainClusterConfigArgs> {
    override fun toJava(): com.pulumi.aws.opensearch.inputs.DomainClusterConfigArgs =
        com.pulumi.aws.opensearch.inputs.DomainClusterConfigArgs.builder()
            .coldStorageOptions(
                coldStorageOptions?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .dedicatedMasterCount(dedicatedMasterCount?.applyValue({ args0 -> args0 }))
            .dedicatedMasterEnabled(dedicatedMasterEnabled?.applyValue({ args0 -> args0 }))
            .dedicatedMasterType(dedicatedMasterType?.applyValue({ args0 -> args0 }))
            .instanceCount(instanceCount?.applyValue({ args0 -> args0 }))
            .instanceType(instanceType?.applyValue({ args0 -> args0 }))
            .multiAzWithStandbyEnabled(multiAzWithStandbyEnabled?.applyValue({ args0 -> args0 }))
            .warmCount(warmCount?.applyValue({ args0 -> args0 }))
            .warmEnabled(warmEnabled?.applyValue({ args0 -> args0 }))
            .warmType(warmType?.applyValue({ args0 -> args0 }))
            .zoneAwarenessConfig(
                zoneAwarenessConfig?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .zoneAwarenessEnabled(zoneAwarenessEnabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DomainClusterConfigArgs].
 */
@PulumiTagMarker
public class DomainClusterConfigArgsBuilder internal constructor() {
    private var coldStorageOptions: Output<DomainClusterConfigColdStorageOptionsArgs>? = null

    private var dedicatedMasterCount: Output<Int>? = null

    private var dedicatedMasterEnabled: Output<Boolean>? = null

    private var dedicatedMasterType: Output<String>? = null

    private var instanceCount: Output<Int>? = null

    private var instanceType: Output<String>? = null

    private var multiAzWithStandbyEnabled: Output<Boolean>? = null

    private var warmCount: Output<Int>? = null

    private var warmEnabled: Output<Boolean>? = null

    private var warmType: Output<String>? = null

    private var zoneAwarenessConfig: Output<DomainClusterConfigZoneAwarenessConfigArgs>? = null

    private var zoneAwarenessEnabled: Output<Boolean>? = null

    /**
     * @param value Configuration block containing cold storage configuration. Detailed below.
     */
    @JvmName("jjbeuodrnlqvbrta")
    public suspend fun coldStorageOptions(`value`: Output<DomainClusterConfigColdStorageOptionsArgs>) {
        this.coldStorageOptions = value
    }

    /**
     * @param value Number of dedicated main nodes in the cluster.
     */
    @JvmName("dkddwsgmjjaimyyk")
    public suspend fun dedicatedMasterCount(`value`: Output<Int>) {
        this.dedicatedMasterCount = value
    }

    /**
     * @param value Whether dedicated main nodes are enabled for the cluster.
     */
    @JvmName("nrnvqvhemfvvngem")
    public suspend fun dedicatedMasterEnabled(`value`: Output<Boolean>) {
        this.dedicatedMasterEnabled = value
    }

    /**
     * @param value Instance type of the dedicated main nodes in the cluster.
     */
    @JvmName("ujwkcansuprsaucf")
    public suspend fun dedicatedMasterType(`value`: Output<String>) {
        this.dedicatedMasterType = value
    }

    /**
     * @param value Number of instances in the cluster.
     */
    @JvmName("sqqmorjvwajkccpd")
    public suspend fun instanceCount(`value`: Output<Int>) {
        this.instanceCount = value
    }

    /**
     * @param value Instance type of data nodes in the cluster.
     */
    @JvmName("tiaieprcyokgutyd")
    public suspend fun instanceType(`value`: Output<String>) {
        this.instanceType = value
    }

    /**
     * @param value Whether a multi-AZ domain is turned on with a standby AZ. For more information, see [Configuring a multi-AZ domain in Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/managedomains-multiaz.html).
     */
    @JvmName("vkaeeyljbpmhedcc")
    public suspend fun multiAzWithStandbyEnabled(`value`: Output<Boolean>) {
        this.multiAzWithStandbyEnabled = value
    }

    /**
     * @param value Number of warm nodes in the cluster. Valid values are between `2` and `150`. `warm_count` can be only and must be set when `warm_enabled` is set to `true`.
     */
    @JvmName("gbyxxevhvupbfbia")
    public suspend fun warmCount(`value`: Output<Int>) {
        this.warmCount = value
    }

    /**
     * @param value Whether to enable warm storage.
     */
    @JvmName("ddqyyhcesgtritgt")
    public suspend fun warmEnabled(`value`: Output<Boolean>) {
        this.warmEnabled = value
    }

    /**
     * @param value Instance type for the OpenSearch cluster's warm nodes. Valid values are `ultrawarm1.medium.search`, `ultrawarm1.large.search` and `ultrawarm1.xlarge.search`. `warm_type` can be only and must be set when `warm_enabled` is set to `true`.
     */
    @JvmName("roaqtooswtqcqqqs")
    public suspend fun warmType(`value`: Output<String>) {
        this.warmType = value
    }

    /**
     * @param value Configuration block containing zone awareness settings. Detailed below.
     */
    @JvmName("aeqmatldvugdrmfi")
    public suspend fun zoneAwarenessConfig(`value`: Output<DomainClusterConfigZoneAwarenessConfigArgs>) {
        this.zoneAwarenessConfig = value
    }

    /**
     * @param value Whether zone awareness is enabled, set to `true` for multi-az deployment. To enable awareness with three Availability Zones, the `availability_zone_count` within the `zone_awareness_config` must be set to `3`.
     */
    @JvmName("rvdudeheaukrbrcs")
    public suspend fun zoneAwarenessEnabled(`value`: Output<Boolean>) {
        this.zoneAwarenessEnabled = value
    }

    /**
     * @param value Configuration block containing cold storage configuration. Detailed below.
     */
    @JvmName("opuotjwdpglpcslk")
    public suspend fun coldStorageOptions(`value`: DomainClusterConfigColdStorageOptionsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.coldStorageOptions = mapped
    }

    /**
     * @param argument Configuration block containing cold storage configuration. Detailed below.
     */
    @JvmName("lfaosomjxbyvmllb")
    public suspend fun coldStorageOptions(argument: suspend DomainClusterConfigColdStorageOptionsArgsBuilder.() -> Unit) {
        val toBeMapped = DomainClusterConfigColdStorageOptionsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.coldStorageOptions = mapped
    }

    /**
     * @param value Number of dedicated main nodes in the cluster.
     */
    @JvmName("xhawisjergdgkckk")
    public suspend fun dedicatedMasterCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dedicatedMasterCount = mapped
    }

    /**
     * @param value Whether dedicated main nodes are enabled for the cluster.
     */
    @JvmName("goprjuenprlevdfx")
    public suspend fun dedicatedMasterEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dedicatedMasterEnabled = mapped
    }

    /**
     * @param value Instance type of the dedicated main nodes in the cluster.
     */
    @JvmName("kscujpwtjyimotwh")
    public suspend fun dedicatedMasterType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dedicatedMasterType = mapped
    }

    /**
     * @param value Number of instances in the cluster.
     */
    @JvmName("mdblfkcsymjnclrn")
    public suspend fun instanceCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.instanceCount = mapped
    }

    /**
     * @param value Instance type of data nodes in the cluster.
     */
    @JvmName("iteytvnxeqlinnno")
    public suspend fun instanceType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.instanceType = mapped
    }

    /**
     * @param value Whether a multi-AZ domain is turned on with a standby AZ. For more information, see [Configuring a multi-AZ domain in Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/managedomains-multiaz.html).
     */
    @JvmName("bwtpdlmfjjllyjul")
    public suspend fun multiAzWithStandbyEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.multiAzWithStandbyEnabled = mapped
    }

    /**
     * @param value Number of warm nodes in the cluster. Valid values are between `2` and `150`. `warm_count` can be only and must be set when `warm_enabled` is set to `true`.
     */
    @JvmName("qmrmghugjlcwfnck")
    public suspend fun warmCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.warmCount = mapped
    }

    /**
     * @param value Whether to enable warm storage.
     */
    @JvmName("wpdovbpyvofnebgm")
    public suspend fun warmEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.warmEnabled = mapped
    }

    /**
     * @param value Instance type for the OpenSearch cluster's warm nodes. Valid values are `ultrawarm1.medium.search`, `ultrawarm1.large.search` and `ultrawarm1.xlarge.search`. `warm_type` can be only and must be set when `warm_enabled` is set to `true`.
     */
    @JvmName("voynhpcmbpdfywfj")
    public suspend fun warmType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.warmType = mapped
    }

    /**
     * @param value Configuration block containing zone awareness settings. Detailed below.
     */
    @JvmName("dlkvdpevvxdqpxsb")
    public suspend fun zoneAwarenessConfig(`value`: DomainClusterConfigZoneAwarenessConfigArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.zoneAwarenessConfig = mapped
    }

    /**
     * @param argument Configuration block containing zone awareness settings. Detailed below.
     */
    @JvmName("eowayvtcpwaoqiyk")
    public suspend fun zoneAwarenessConfig(argument: suspend DomainClusterConfigZoneAwarenessConfigArgsBuilder.() -> Unit) {
        val toBeMapped = DomainClusterConfigZoneAwarenessConfigArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.zoneAwarenessConfig = mapped
    }

    /**
     * @param value Whether zone awareness is enabled, set to `true` for multi-az deployment. To enable awareness with three Availability Zones, the `availability_zone_count` within the `zone_awareness_config` must be set to `3`.
     */
    @JvmName("xeucwtacluxiddaq")
    public suspend fun zoneAwarenessEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.zoneAwarenessEnabled = mapped
    }

    internal fun build(): DomainClusterConfigArgs = DomainClusterConfigArgs(
        coldStorageOptions = coldStorageOptions,
        dedicatedMasterCount = dedicatedMasterCount,
        dedicatedMasterEnabled = dedicatedMasterEnabled,
        dedicatedMasterType = dedicatedMasterType,
        instanceCount = instanceCount,
        instanceType = instanceType,
        multiAzWithStandbyEnabled = multiAzWithStandbyEnabled,
        warmCount = warmCount,
        warmEnabled = warmEnabled,
        warmType = warmType,
        zoneAwarenessConfig = zoneAwarenessConfig,
        zoneAwarenessEnabled = zoneAwarenessEnabled,
    )
}
